==> estateplat-common-1.2.3-20180503.080841-73-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXygl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/17
 * @description 不动产信用管理
 */
@Table(name = "bdc_xygl")
public class BdcXygl implements Serializable {

    //信用管理id
    @Id
    private String xyglid;
    //人员信息ID
    private String ryxxid;
    //权利人
    private String qlrmc;
    //权利人身份证件种类
    private String qlrsfzjzl;
    //权利人证件号
    private String qlrzjh;
    //权利人通讯地址
    private String qlrtxdz;
    //备注
    private String bz;
    //数据来源
    private String sjly;
    public String getXyglid() {
        return xyglid;
    }

    public void setXyglid(String xyglid) {
        this.xyglid = xyglid;
    }

    public String getRyxxid() {
        return ryxxid;
    }

    public void setRyxxid(String ryxxid) {
        this.ryxxid = ryxxid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }
}

==> estateplat-common-1.2.3-20180620.083639-127-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXygl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

/**
 * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
 * @version 1.0, 2016/12/17
 * @description 不动产信用管理
 */
@Table(name = "bdc_xygl")
public class BdcXygl implements Serializable {

    //信用管理id
    @Id
    private String xyglid;
    //人员信息ID
    private String ryxxid;
    //权利人
    private String qlrmc;
    //权利人身份证件种类
    private String qlrsfzjzl;
    //权利人证件号
    private String qlrzjh;
    //权利人通讯地址
    private String qlrtxdz;
    //备注
    private String bz;
    //数据来源
    private String sjly;
    //权利人性质
    private String qlrxz;
    //权利人联系电话
    private String qlrlxdh;
    //权利人邮编
    private String qlryb;
    //权利人法定代表人
    private String qlrfddbr;

    public String getXyglid() {
        return xyglid;
    }

    public void setXyglid(String xyglid) {
        this.xyglid = xyglid;
    }

    public String getRyxxid() {
        return ryxxid;
    }

    public void setRyxxid(String ryxxid) {
        this.ryxxid = ryxxid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjly() {
        return sjly;
    }

    public void setSjly(String sjly) {
        this.sjly = sjly;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getQlryb() {
        return qlryb;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public String getQlrfddbr() {
        return qlrfddbr;
    }

    public void setQlrfddbr(String qlrfddbr) {
        this.qlrfddbr = qlrfddbr;
    }
}
